<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 29, 2013 9:29:42 AM
 * @version $Rev$
 */

/**
 * Job class
 * Used to ....
 */
class Entity_Writer_Candidate extends Entity_Writer {
	
	protected $type = WP_Constants::ENTITY_TYPE_CANDIDATE;
    private $settings = array();
    private $candidateFields = array();
	
    public function __construct($dataDictionary, $settings, $customFields = array()) {
        parent::__construct($dataDictionary, $customFields);
        $this->settings = $settings;
        $this->candidateFields = $customFields;
    }


    public function getContent()
	{   
        $content = $this->settings['posttemplate'];
		return $content;
	}

	public function getTitle() 
	{
        if(isset($this->settings['display_name']))
        {
            switch($this->settings['display_name'])
            {
                case 'functionname':
                    $this->dataDictionary['_name'] = @$this->candidateFields['functionName'];
                    break;
                case 'fullname':
                    $this->dataDictionary['_name'] = @$this->dataDictionary['name'];
                    break;
                case 'firstname':
                    $this->dataDictionary['_name'] = @$this->dataDictionary['firstName'];
                    break;
                case 'initials':
                    $this->dataDictionary['_name'] = @$this->dataDictionary['initials'];
                    break;
                default:
                 break;   
            }
        }
        
        
        
		if(isset($this->dataDictionary['_name']))
		{
			return $this->dataDictionary['_name'];
		} else {
            if(isset($this->dataDictionary['initials'])) return @$this->dataDictionary['initials'];
            if(isset($this->dataDictionary['firstName'])) return @$this->dataDictionary['firstName'];
            if(isset($this->dataDictionary['name'])) return @$this->dataDictionary['name'];
        }
		
		return '';
	}
	
	public function getCorrespondentID()
	{
		if(isset($this->dataDictionary['guid']))
		{
			return $this->dataDictionary['guid'];
		}
		
		return false;
	}
	
	public function getPublishDate()
	{
		if(isset($this->dataDictionary['date']))
		{
			return $this->dataDictionary['date'];
		}
		
		return date('Y-m-d H:i:s');
	}
	
	public function postWrite($post_id)
	{
		// do translation
		
		// set category
		
		//$categoryKey = 'Candidates';
        
        $language = $this->interfacer->language_current();
        $labels = Utils_Labels::get($language);
        $resource = 'resource_category_'. str_replace('.', '_', 'general.header.candidates');
        $categoryKey = Environment_Settings::_setting_get($resource . '_' . $language);
        if(!$categoryKey) $categoryKey = $labels['general.header.candidates'];
        
        $category_f1 = array($categoryKey, @$this->dataDictionary['functionGroup1'], @$this->dataDictionary['function1']);
        $this->interfacer->entity_link_category($post_id, $category_f1);
        
        $category_f2 = array($categoryKey, @$this->dataDictionary['functionGroup2'], @$this->dataDictionary['function2']);
        $this->interfacer->entity_link_category($post_id, $category_f2);
        
        $category_f3 = array($categoryKey, @$this->dataDictionary['functionGroup3'], @$this->dataDictionary['function3']);
        $this->interfacer->entity_link_category($post_id, $category_f3);
        
        $education1Levels = array();
        $education2Levels = array();
        $education3Levels = array();
        
        if (isset($this->dataDictionary['educations'])) {
            foreach($this->dataDictionary['educations'] as $education)
            {
                $education1Levels[] = $education['education1'];
                $education2Levels[] = $education['education2'];
                $education3Levels[] = $education['education3'];
            }
        }
        
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_CANDIDATE_EDUCATION_LEVEL_1, $post_id, $education1Levels );
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_CANDIDATE_EDUCATION_LEVEL_2, $post_id, $education2Levels );
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_CANDIDATE_EDUCATION_LEVEL_3, $post_id, $education3Levels );
        
        $this->interfacer->entity_set_taxonomy(WP_Constants::TAXONOMY_WORKLOCATION, $post_id, array(@$this->candidateFields['location']));
	}
	
	public function getFragment($post_id)
	{
		$link = $this->interfacer->get_post_permalink($post_id);
		
        $content  = "<h4 class='cx_h4'><a href='$link'>{$this->getTitle()}</a></h4>";

        if(isset($this->settings['showid']) && $this->settings['showid'] == 'on' )
        {
            $content .= '<p class="candidate_id">ID: ' .$this->getCorrespondentID().'<p>';
        }
        
        $excerptLength = 55;
        $reviewInfo = $this->text_cut(@$this->dataDictionary['reviewInfo'], $excerptLength);
        
        $content .= $reviewInfo;
		
        return $content;
	}
    
    private function text_cut($text, $length = 200, $dots = true) {
        $text = trim(preg_replace('#[\s\n\r\t]{2,}#', ' ', $text));
        $text_temp = $text;
        while (substr($text, $length, 1) != " ") { $length++; if ($length > strlen($text)) { break; } }
        $text = substr($text, 0, $length);
        return $text . ( ( $dots == true && $text != '' && strlen($text_temp) > $length ) ? '...' : ''); 
    }

    public function getSlug() {
        return sanitize_title_with_dashes($this->getTitle());
    }
}